@@ -10,21 +10,22 @@ from urllib.parse import urlparse, urlunparse
 import requests
 # noinspection PyPackageRequirements
 import urllib3
-from httpie import __version__
-from httpie.cli.dicts import RequestHeadersDict
-from httpie.plugins.registry import plugin_manager
-from httpie.sessions import get_httpie_session
-from httpie.ssl import AVAILABLE_SSL_VERSION_ARG_MAPPING, HTTPieHTTPSAdapter
-from httpie.uploads import (
+from . import __version__
+from .cli.dicts import RequestHeadersDict
+from .constants import UTF8
+from .plugins.registry import plugin_manager
+from .sessions import get_httpie_session
+from .ssl import AVAILABLE_SSL_VERSION_ARG_MAPPING, HTTPieHTTPSAdapter
+from .uploads import (
     compress_request, prepare_request_body,
     get_multipart_data_and_content_type,
 )
-from httpie.utils import get_expired_cookies, repr_dict
+from .utils import get_expired_cookies, repr_dict
 
 
 urllib3.disable_warnings()
 
-FORM_CONTENT_TYPE = 'application/x-www-form-urlencoded; charset=utf-8'
+FORM_CONTENT_TYPE = f'application/x-www-form-urlencoded; charset={UTF8}'
 JSON_CONTENT_TYPE = 'application/json'
 JSON_ACCEPT = f'{JSON_CONTENT_TYPE}, */*;q=0.5'
 DEFAULT_UA = f'HTTPie/{__version__}'
@@ -104,9 +105,8 @@ def collect_messages(
                     **send_kwargs,
                 )
 
-            # noinspection PyProtectedMember
             expired_cookies += get_expired_cookies(
-                headers=response.raw._original_response.msg._headers
+                response.headers.get('Set-Cookie', '')
             )
 
             response_count += 1
@@ -134,7 +134,7 @@ def collect_messages(
 # noinspection PyProtectedMember
 @contextmanager
 def max_headers(limit):
-    # <https://github.com/jakubroztocil/httpie/issues/802>
+    # <https://github.com/httpie/httpie/issues/802>
     # noinspection PyUnresolvedReferences
     orig = http.client._MAXHEADERS
     http.client._MAXHEADERS = limit or float('Inf')
@@ -188,8 +188,8 @@ def finalize_headers(headers: RequestHeadersDict) -> RequestHeadersDict:
             # Also, requests raises `InvalidHeader` for leading spaces.
             value = value.strip()
             if isinstance(value, str):
-                # See <https://github.com/jakubroztocil/httpie/issues/212>
-                value = value.encode('utf8')
+                # See <https://github.com/httpie/httpie/issues/212>
+                value = value.encode()
         final_headers[name] = value
     return final_headers
 
@@ -213,11 +213,10 @@ def make_default_headers(args: argparse.Namespace) -> RequestHeadersDict:
 
 
 def make_send_kwargs(args: argparse.Namespace) -> dict:
-    kwargs = {
+    return {
         'timeout': args.timeout or None,
         'allow_redirects': False,
     }
-    return kwargs
 
 
 def make_send_kwargs_mergeable_from_env(args: argparse.Namespace) -> dict:
@@ -226,7 +225,7 @@ def make_send_kwargs_mergeable_from_env(args: argparse.Namespace) -> dict:
         cert = args.cert
         if args.cert_key:
             cert = cert, args.cert_key
-    kwargs = {
+    return {
         'proxies': {p.key: p.value for p in args.proxy},
         'stream': True,
         'verify': {
@@ -237,7 +236,6 @@ def make_send_kwargs_mergeable_from_env(args: argparse.Namespace) -> dict:
         }.get(args.verify.lower(), args.verify),
         'cert': cert,
     }
-    return kwargs
 
 
 def make_request_kwargs(
@@ -279,7 +277,7 @@ def make_request_kwargs(
             content_type=args.headers.get('Content-Type'),
         )
 
-    kwargs = {
+    return {
         'method': args.method.lower(),
         'url': args.url,
         'headers': headers,
@@ -294,8 +292,6 @@ def make_request_kwargs(
         'params': args.params.items(),
     }
 
-    return kwargs
-
 
 def ensure_path_as_is(orig_url: str, prepped_url: str) -> str:
     """
@@ -304,7 +300,7 @@ def ensure_path_as_is(orig_url: str, prepped_url: str) -> str:
     untouched because other (welcome) processing on the URL might have
     taken place.
 
-    <https://github.com/jakubroztocil/httpie/issues/895>
+    <https://github.com/httpie/httpie/issues/895>
 
 
     <https://ec.haxx.se/http/http-basics#path-as-is>
@@ -320,5 +316,4 @@ def ensure_path_as_is(orig_url: str, prepped_url: str) -> str:
         **parsed_prepped._asdict(),
         'path': parsed_orig.path,
     }
-    final_url = urlunparse(tuple(final_dict.values()))
-    return final_url
+    return urlunparse(tuple(final_dict.values()))
