@@ -1,15 +1,15 @@
-from __future__ import absolute_import
 import json
 
-from httpie.plugins import FormatterPlugin
-
-
-DEFAULT_INDENT = 4
+from ...plugins import FormatterPlugin
 
 
 class JSONFormatter(FormatterPlugin):
 
-    def format_body(self, body, mime):
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.enabled = self.format_options['json']['format']
+
+    def format_body(self, body: str, mime: str) -> str:
         maybe_json = [
             'json',
             'javascript',
@@ -26,8 +26,8 @@ class JSONFormatter(FormatterPlugin):
                 # unicode escapes to improve readability.
                 body = json.dumps(
                     obj=obj,
-                    sort_keys=True,
+                    sort_keys=self.format_options['json']['sort_keys'],
                     ensure_ascii=False,
-                    indent=DEFAULT_INDENT
+                    indent=self.format_options['json']['indent']
                 )
         return body
