@@ -1,9 +1,11 @@
+from abc import ABCMeta, abstractmethod
 from itertools import chain
 from typing import Callable, Iterable, Union
 
-from httpie.context import Environment
-from httpie.models import HTTPMessage
-from httpie.output.processing import Conversion, Formatting
+from ..context import Environment
+from ..constants import UTF8
+from ..models import HTTPMessage
+from .processing import Conversion, Formatting
 
 
 BINARY_SUPPRESSED_NOTICE = (
@@ -24,7 +26,7 @@ class BinarySuppressedError(DataSuppressedError):
     message = BINARY_SUPPRESSED_NOTICE
 
 
-class BaseStream:
+class BaseStream(metaclass=ABCMeta):
     """Base HTTP message output stream class."""
 
     def __init__(
@@ -48,11 +50,11 @@ class BaseStream:
 
     def get_headers(self) -> bytes:
         """Return the headers' bytes."""
-        return self.msg.headers.encode('utf8')
+        return self.msg.headers.encode()
 
+    @abstractmethod
     def iter_body(self) -> Iterable[bytes]:
         """Return an iterator over the message body."""
-        raise NotImplementedError()
 
     def __iter__(self) -> Iterable[bytes]:
         """Return an iterator over `self.msg`."""
@@ -104,8 +106,8 @@ class EncodedStream(BaseStream):
         else:
             # Preserve the message encoding.
             output_encoding = self.msg.encoding
-        # Default to utf8 when unsure.
-        self.output_encoding = output_encoding or 'utf8'
+        # Default to UTF-8 when unsure.
+        self.output_encoding = output_encoding or UTF8
 
     def iter_body(self) -> Iterable[bytes]:
         for line, lf in self.msg.iter_lines(self.CHUNK_SIZE):
